.. pydgrid
pydgrid: Python Distribution Grid simulator



:Name: pydgrid
:Website: https://pydgrid.github.io/
:Author: Juan Manuel Mauricio |orcid|
:Version: 0.5.1


   
.. |orcid| image:: https://img.shields.io/badge/id-0000--0002--2187--161X-a6ce39.svg
   :target: http://orcid.org/0000-0002-5702-0198

   
.. image:: https://readthedocs.org/projects/pydgrid/badge/?version=latest
    :target: https://pydgrid.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status   

.. |license| image:: https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square
   :target: https://github.com/pydgrid/pydgrid/raw/master/COPYING
   
